package config

import (
	"github.com/spf13/viper"
	"log"
)

type Config struct {
	ListenAddress  string `mapstructure:"HIVEDAV_LISTEN_ADDRESS"`
	ListenPort     int    `mapstructure:"HIVEDAV_LISTEN_PORT"`
	CaldavUri      string `mapstructure:"HIVEDAV_CALDAV_URI"`
	Calendar       int    `mapstructure:"HIVEDAV_CALENDAR"`
	CaldavUser     string `mapstructure:"HIVEDAV_CALDAV_USER"`
	CaldavPassword string `mapstructure:"HIVEDAV_CALDAV_PASSWORD"`
}

func (c *Config) LoadConfig(path string) (*Config, error) {
	viper.AddConfigPath(path)
	// look for config file with name "app"
	viper.SetConfigName("app")
	// look for config file with name "app.env"
	viper.SetConfigType("env")

	// override config file vars with env vars
	viper.AutomaticEnv()
	viper.SetEnvPrefix("HIVEDAV")

	// define some defaults
	viper.SetDefault("HIVEDAV_LISTEN_PORT", 3737)
	viper.SetDefault("HIVEDAV_LISTEN_ADDRESS", "[::]")
	viper.SetDefault("HIVEDAV_CALENDAR", 0)

	err := viper.ReadInConfig()
	if err != nil {
		log.Println("app.env config file not found")
		return nil, err
	}

	err = viper.Unmarshal(c)
	if err != nil {
		log.Println("Error unmarshalling config")
		return nil, err
	}
	return c, nil
}
